from .Conv.ConvLayer import ConvLayer
from .Dense.DenseLayer import DenseLayer
from .Pooling.PoolingLayer import PoolingLayer
from .Flatten.FlattenLayer import FlattenLayer
#from .OutputLayer import OutputLayer
from .Model.NetworkModel import NetworkModel
name = "inspectnn"
__version__ = "0.1.0"
__author__ = "Salvatore Barone, Filippo Ferrandino"
__credits__ = "Department of Electrical Engineering and Information Technologies, University of Naples Federico II, Via Claudio 21, Naples, Italy"
